# Known instances of Eltern-Portal

Identifier | Url                                   | School
:--------- | :------------------------------------ | :-----
abendrsau  | https://abendrsau.eltern-portal.org   | Abendrealschule Augsburg, 86152 Augsburg
abstgym    | https://abstgym.eltern-portal.org     | Anton-Bruckner-Gymnasium Straubing, 94315 Straubing
aegymuc    | https://aegymuc.eltern-portal.org     | Albert-Einstein-Gymnasium München, 81545 München
agbersau   | https://agbersau.eltern-portal.org    | Agnes-Bernauer-Schule - Realschule für Mädchen, 86152 Augsburg
akgkitz    | https://akgkitz.eltern-portal.org     | Armin-Knab-Gymnasium Kitzingen, 97318 Kitzingen
alblaugy   | https://alblaugy.eltern-portal.org    | Albertus-Gymnasium Lauingen, 89415 Lauingen (Donau)
alkemgym   | https://alkemgym.eltern-portal.org    | Allgäu-Gymnasium Kempten, 87435 Kempten (Allgäu)
amgydie    | https://amgydie.eltern-portal.org     | Ammersee-Gymnasium Dießen, 86911 Dießen am Ammersee
amorgym    | https://amorgym.eltern-portal.org     | Karl-Ernst-Gymnasium Amorbach, 63916 Amorbach
anfragym   | https://anfragym.eltern-portal.org    | Anne-Frank-Gymnasium Erding, 85435 Erding
ansfobo    | https://ansfobo.eltern-portal.org     | Berufliche Oberschule Ansbach, 91522 Ansbach
apgying    | https://apgying.eltern-portal.org     | Apian-Gymnasium Ingolstadt, 85051 Ingolstadt
asamgymuc  | https://asamgymuc.eltern-portal.org   | Asam-Gymnasium München, 81541 München
astipagym  | https://astipagym.eltern-portal.org   | Adalbert-Stifter-Gymnasium Passau, 94032 Passau
aufreugy   | https://aufreugy.eltern-portal.org    | Auersperg-Gymnasium, 94034 Passau
augystan   | https://augystan.eltern-portal.org    | Gymnasium bei St. Anna, 86159 Augsburg
augysteph  | https://augysteph.eltern-portal.org   | Gymnasium bei St. Stephan Augsburg, 86152 Augsburg
austafach  | https://austafach.eltern-portal.org   | Staatsinstitut für die Ausbildung von Fachlehrern
avegybu    | https://avegybu.eltern-portal.org     | Aventinus-Gymnasium Burghausen, 84489 Burghausen
avhgym     | https://avhgym.eltern-portal.org      | Alexander-von-Humboldt-Gymnasium Schweinfurt, 97424 Schweinfurt
bagyeich   | https://bagyeich.eltern-portal.org    | Eichendorff-Gymnasium Bamberg, 96050 Bamberg
baiblgy    | https://baiblgy.eltern-portal.org     | Gymnasium Bad Aibling, 83043 Bad Aibling
baykola    | https://baykola.eltern-portal.org     | Bayernkolleg Augsburg, 86169 Augsburg
bbgymuc    | https://bbgymuc.eltern-portal.org     | Städtisches Bertolt-Brecht-Gymnasium München, 81243 München
bngmh      | https://bngmh.eltern-portal.org       | Balthasar-Neumann-Gymnasium Marktheidenfeld, 97828 Marktheidenfeld
bskoegy    | https://bskoegy.eltern-portal.org     | Benedikt-Stattler-Gymnasium Bad Kötzting, 93444 Bad Kötzting
bszhof2ws  | https://bszhof2ws.eltern-portal.org   | Staatliche Wirtschaftsschule Hof, 95028 Hof
bugymal    | https://bugymal.eltern-portal.org     | Burkhart-Gymnasium Mallersdorf-Pfaffenberg, 84066 Mallersdorf-Pfaffenberg
bukugym    | https://bukugym.eltern-portal.org     | Gymnasium Burgkunstadt, 96224 Burgkunstadt
casigym    | https://casigym.eltern-portal.org     | Gymnasium Casimirianum Coburg, 96450 Coburg
cavigy     | https://cavigy.eltern-portal.org      | Caspar-Vischer-Gymnasium Kulmbach, 95326 Kulmbach
cjtgylau   | https://cjtgylau.eltern-portal.org    | Christoph-Jacob-Treu-Gymnasium Lauf, 91207 Lauf an der Pegnitz
comgydeg   | https://comgydeg.eltern-portal.org    | Comenius-Gymnasium Deggendorf
cpgygil    | https://cpgygil.eltern-portal.org     | Christoph Probst Gymnasium Gilching, 82205 Gilching
csgying    | https://csgying.eltern-portal.org     | Christoph-Scheiner-Gymnasium, 85049 Ingolstadt
dantemuc   | https://dantemuc.eltern-portal.org    | Dante-Gymnasium München, 81371 München
degfobo    | https://degfobo.eltern-portal.org     | Aloys-Fischer-Schule Deggendorf, 94469 Deggendorf
degyaich   | https://degyaich.eltern-portal.org    | Deutschherren-Gymnasium Aichach, 86551 Aichach
deigs      | https://deigs.eltern-portal.org       | Grundschule Deisenhofen, 82041 Oberhaching
deroko     | https://deroko.eltern-portal.org      | Robert-Koch-Gymnasium Deggendorf, 94469 Deggendorf
dilgyjms   | https://dilgyjms.eltern-portal.org    | Johann-Michael-Sailer-Gymnasium, 89407 Dillingen a.d.Donau
dingogym   | https://dingogym.eltern-portal.org    | Gymnasium Dingolfing, 84130 Dingolfing
domfreigy  | https://domfreigy.eltern-portal.org   | Dom-Gymnasium Freising, 85354 Freising
domgyreg   | https://domgyreg.eltern-portal.org    | Gymnasium der Regensburger Domspatzen, 93055 Regensburg
donaugym   | https://donaugym.eltern-portal.org    | Gymnasium Donauwörth, 86609 Donauwörth
dorfgym    | https://dorfgym.eltern-portal.org     | Gymnasium Dorfen, 84405 Dorfen
dzglan     | https://dzglan.eltern-portal.org      | Dominikus-Zimmermann-Gymnasium Landsberg am Lech, 86899 Landsberg am Lech
ebgymuc    | https://ebgymuc.eltern-portal.org     | Städtisches Elsa-Brändström-Gymnasium München, 81241 München
eckegym    | https://eckegym.eltern-portal.org     | Gymnasium Eckental, 90542 Eckental
ehrforgy   | https://ehrforgy.eltern-portal.org    | Ehrenbürg-Gymnasium Forchheim, 91301 Forchheim
emagyha    | https://emagyha.eltern-portal.org     | Ernst-Mach-Gymnasium Haar, 85540 Haar
engyerl    | https://engyerl.eltern-portal.org     | Emmy-Noether-Gymnasium Erlangen, 91058 Erlangen
ergogym    | https://ergogym.eltern-portal.org     | Gymnasium Ergolding, 84030 Ergolding
ergosfz    | https://ergosfz.eltern-portal.org     | Sonderpädagogisches Förderzentrum Landshut-Land, 84030 Ergolding
esgymuc    | https://esgymuc.eltern-portal.org     | Erzbischöfliches Edith-Stein-Gymnasium, 81667 München
etahgybam  | https://etahgybam.eltern-portal.org   | E.T.A. Hoffmann-Gymnasium Bamberg, 96049 Bamberg
evbspar    | https://evbspar.eltern-portal.org     | Emil-von-Behring-Gymnasium Spardorf
fagyneu    | https://fagyneu.eltern-portal.org     | Friedrich-Alexander-Gymnasium, 91413 Neustadt an der Aisch
ffbgrg     | https://ffbgrg.eltern-portal.org      | Graf-Rasso-Gymnasium, 82256 Fürstenfeldbruck
finrogym   | https://finrogym.eltern-portal.org    | Sebastian-Finsterwalder-Gymnasium Rosenheim, 83022 Rosenheim
fkgwue     | https://fkgwue.eltern-portal.org      | Friedrich-Koenig-Gymnasium, 97082 Würzburg
flgybam    | https://flgybam.eltern-portal.org     | Franz-Ludwig-Gymnasium Bamberg
framagym   | https://framagym.eltern-portal.org    | Franz-Marc-Gymnasium, 85570 Markt Schwaben
freicamgy  | https://freicamgy.eltern-portal.org   | Camerloher-Gymnasium Freising, 85354 Freising
freigymuc  | https://freigymuc.eltern-portal.org   | Gymnasium Freiham, 81248 München
fridgyerl  | https://fridgyerl.eltern-portal.org   | Gymnasium Fridericianum, 19053 Schwerin
friebos    | https://friebos.eltern-portal.org     | Berufliche Oberschule Friedberg, 86316 Friedberg
friedgym   | https://friedgym.eltern-portal.org    | Gymnasium Friedberg, 86316 Friedberg
fuerimuc   | https://fuerimuc.eltern-portal.org    | Gymnasium Fürstenried, 81475 München
gagymain   | https://gagymain.eltern-portal.org    | Gabelsberger-Gymnasium Mainburg, 84048 Mainburg
gargym     | https://gargym.eltern-portal.org      | Gymnasium Gars, 83536
gesaholl   | https://gesaholl.eltern-portal.org    | Staatliche Gesamtschule Hollfeld
gisgymuc   | https://gisgymuc.eltern-portal.org    | Gisela-Gymnasium München, 80801 München
gk         | https://gk.eltern-portal.org          | Gymnasium Kirchheim, 85551 Kirchheim bei München
gmgbay     | https://gmgbay.eltern-portal.org      | Graf-Münster-Gymnasium Bayreuth, 95444 Bayreuth
gmshaag    | https://gmshaag.eltern-portal.org     | Grund- und Mittelschule Haag i. OB, 83527 Haag in Oberbayern
gmslaufen  | https://gmslaufen.eltern-portal.org   | Ruperti Grund- und Mittelschule Laufen, 83410 Laufen
gn         | https://gn.eltern-portal.org          | Gymnasium Neubiberg, 85579 Neubiberg
gnadgym    | https://gnadgym.eltern-portal.org     | Gnadenthal-Gymnasium Ingolstadt der Diözese Eichstätt
go         | https://go.eltern-portal.org          | Gymnasium Ottobrunn, 85521 Ottobrunn
grafgym    | https://grafgym.eltern-portal.org     | Max-Mannheimer-Gymnasium Grafing, 85567 Grafing bei München
groebegy   | https://groebegy.eltern-portal.org    | Gymnasium Gröbenzell, 82194
gruewagym  | https://gruewagym.eltern-portal.org   | Gymnasium Grünwald, 82031 Grünwald
gsgstu     | https://gsgstu.eltern-portal.org      | Geschwister-Scholl-Gymnasium Stuttgart-Sillenbuch, 70619 Stuttgart
gsuhg      | https://gsuhg.eltern-portal.org       | Grundschule am Sportpark
gykisee    | https://gykisee.eltern-portal.org     | Gymnasium Kirchseeon, 85614
gymmod     | https://gymmod.eltern-portal.org      | Gymnasium Marktoberdorf, 87616 Marktoberdorf
gympan     | https://gympan.eltern-portal.org      | Gymnasium Pfarrkirchen, 84347 Pfarrkirchen
gymzwie    | https://gymzwie.eltern-portal.org     | Gymnasium Zwiesel, 94227 Zwiesel
gypenz     | https://gypenz.eltern-portal.org      | Gymnasium Penzberg, 82377 Penzberg
halegyla   | https://halegyla.eltern-portal.org    | Hans-Leinberger-Gymnasium Landshut, 84034 Landshut
hamfrogy   | https://hamfrogy.eltern-portal.org    | Frobenius-Gymnasium Hammelburg, 97762 Hammelburg
hcgla      | https://hcgla.eltern-portal.org       | Hans-Carossa-Gymnasium, 14089 Berlin
hehegymuc  | https://hehegymuc.eltern-portal.org   | Städt. Heinrich-Heine-Gymnasium
helagyfue  | https://helagyfue.eltern-portal.org   | Helene-Lange-Gymnasium Fürth, 90762 Fürth
heraugy    | https://heraugy.eltern-portal.org     | Gymnasium Herzogenaurach, 91074 Herzogenaurach
hertrogym  | https://hertrogym.eltern-portal.org   | Hertzhaimer-Gymnasium Trostberg, 83308 Trostberg
hilgykem   | https://hilgykem.eltern-portal.org    | Hildegardis-Gymnasium Kempten, 87439 Kempten (Allgäu)
hoesiegym  | https://hoesiegym.eltern-portal.org   | Gymnasium Höhenkirchen-Siegertsbrunn, 85635 Höhenkirchen-Siegertsbrunn
holgyau    | https://holgyau.eltern-portal.org     | Holbein-Gymnasium, 86150 Augsburg
holkigym   | https://holkigym.eltern-portal.org    | Gymnasium Holzkirchen, 83607 Holzkirchen
hoschgym   | https://hoschgym.eltern-portal.org    | Gymnasium Hohenschwangau, 87645
hsgyerl    | https://hsgyerl.eltern-portal.org     | Hermann-Staudinger-Gymnasium Erlenbach a. Main, 63906 Erlenbach am Main
hsgyfue    | https://hsgyfue.eltern-portal.org     | Heinrich-Schliemann-Gymnasium, 90762 Fürth
hsgyhoe    | https://hsgyhoe.eltern-portal.org     | Hanns-Seidel-Gymnasium Hösbach, 63768 Hösbach
hugyvat    | https://hugyvat.eltern-portal.org     | Humboldt-Gymnasium-Vaterstetten, 85598 Vaterstetten
hvbrsau    | https://hvbrsau.eltern-portal.org     | Heinrich-von-Buz Realschule Augsburg, 86154 Augsburg
ickigym    | https://ickigym.eltern-portal.org     | Rainer-Maria-Rilke-Gymnasium Icking, 82057
igtadah    | https://igtadah.eltern-portal.org     | Ignaz-Taschner-Gymnasium, 85221 Dachau
iguerogym  | https://iguerogym.eltern-portal.org   | Ignaz-Günther-Gymnasium Rosenheim, 83022 Rosenheim
illvoegy   | https://illvoegy.eltern-portal.org    | Illertal-Gymnasium Vöhringen, 89269 Vöhringen
indomagy   | https://indomagy.eltern-portal.org    | Gymnasium Markt Indersdorf, 85229 Markt Indersdorf
irmrs      | https://irmrs.eltern-portal.org       | Erzbischöfliche St.-Irmengard-Realschule
jafugyau   | https://jafugyau.eltern-portal.org    | Jakob-Fugger-Gymnasium Augsburg, 86152 Augsburg
jcrgyhof   | https://jcrgyhof.eltern-portal.org    | Johann-Christian-Reinhart-Gymnasium Hof, 95030 Hof
joguwa     | https://joguwa.eltern-portal.org      | Johannes-Gutenberg-Gymnasium Waldkirchen, 94065 Waldkirchen
joheitrau  | https://joheitrau.eltern-portal.org   | Johannes-Heidenhain-Gymnasium Traunreut, 83301 Traunreut
johofrei   | https://johofrei.eltern-portal.org    | Josef-Hofmiller-Gymnasium Freising, 85354 Freising
jonegyro   | https://jonegyro.eltern-portal.org    | Johannes-Nepomuk-Gymnasium, 93352
jpgyho     | https://jpgyho.eltern-portal.org      | Jean-Paul-Gymnasium Hof, 95028 Hof
jsgbk      | https://jsgbk.eltern-portal.org       | Jack-Steinberger-Gymnasium Bad Kissingen, 97688 Bad Kissingen
jsgkarl    | https://jsgkarl.eltern-portal.org     | Johann-Schöner-Gymnasium Karlstadt, 97753 Karlstadt
julineu    | https://julineu.eltern-portal.org     | Justus-von-Liebig-Gymnasium, 86356 Neusäß
jvfgcham   | https://jvfgcham.eltern-portal.org    | Joseph-von-Fraunhofer-Gymnasium Cham, 93413 Cham
kagerd     | https://kagerd.eltern-portal.org      | Korbinian-Aigner-Gymnasium Erding, 85435 Erding
karlsgymuc | https://karlsgymuc.eltern-portal.org  | Karlsgymnasium München, 81243 München
karogyro   | https://karogyro.eltern-portal.org    | Karolinen-Gymnasium Rosenheim, 83022 Rosenheim
kepgywei   | https://kepgywei.eltern-portal.org    | Kepler-Gymnasium Weiden, 92637 Weiden in der Oberpfalz
kgbarei    | https://kgbarei.eltern-portal.org     | Karlsgymnasium Bad Reichenhall, 83435 Bad Reichenhall
khgygrae   | https://khgygrae.eltern-portal.org    | Kurt-Huber-Gymnasium Gräfelfing, 82166 Gräfelfing
klengymuc  | https://klengymuc.eltern-portal.org   | Klenze-Gymnasium München, 81371 München
koebrugy   | https://koebrugy.eltern-portal.org    | Gymnasium Königsbrunn, 86343 Königsbrunn
krogya     | https://krogya.eltern-portal.org      | Kronberg-Gymnasium Aschaffenburg, 63739 Aschaffenburg
ksigym     | https://ksigym.eltern-portal.org      | Kolleg der Schulbrüder Illertissen, 89257 Illertissen
kumagybu   | https://kumagybu.eltern-portal.org    | Kurfürst-Maximilian-Gymnasium Burghausen, 84489 Burghausen
kvc        | https://kvc.eltern-portal.org         | Karl-von-Closen-Gymnasium Eggenfelden
lalegygra  | https://lalegygra.eltern-portal.org   | Landgraf-Leuchtenberg-Gymnasium Grafenau, 94481 Grafenau
landau     | https://landau.eltern-portal.org      | Gymnasium Landau a.d. Isar, 94405 Landau an der Isar
leigyalt   | https://leigyalt.eltern-portal.org    | Leibniz-Gymnasium Altdorf, 90518 Altdorf bei Nürnberg
lessgynu   | https://lessgynu.eltern-portal.org    | Lessing-Gymnasium Neu-Ulm, 89231 Neu-Ulm
liefraurs  | https://liefraurs.eltern-portal.org   | Liebfrauenschule Diessen, 86911 Dießen am Ammersee
lifegymuc  | https://lifegymuc.eltern-portal.org   | Städtisches Lion-Feuchtwanger-Gymnasium München, 80807 München
lindgym    | https://lindgym.eltern-portal.org     | Gymnasium Lindenberg, 88161 Lindenberg im Allgäu
lmguhag    | https://lmguhag.eltern-portal.org     | Lise-Meitner-Gymnasium Unterhaching, 82008 Unterhaching
losgymuc   | https://losgymuc.eltern-portal.org    | Städtisches Louise-Schroeder-Gymnasium München, 80999 München
lshmar     | https://lshmar.eltern-portal.org      | Gymnasium Landschulheim Marquartstein, 83250
lsising    | https://lsising.eltern-portal.org     | Landschulheim Schloss Ising am Chiemsee, 83339
lskempf    | https://lskempf.eltern-portal.org     | Landschulheim Kempfenhausen, 82335
ltgyprie   | https://ltgyprie.eltern-portal.org    | Ludwig-Thoma-Gymnasium, 83209 Prien am Chiemsee
ludgymuc   | https://ludgymuc.eltern-portal.org    | Ludwigsgymnasium München, 81377 München
ludgystra  | https://ludgystra.eltern-portal.org   | Ludwigsgymnasium Straubing, 94315 Straubing
luigywas   | https://luigywas.eltern-portal.org    | Luitpold-Gymnasium Wasserburg am Inn, 83512 Wasserburg am Inn
luise      | https://luise.eltern-portal.org       | Städtisches Luisengymnasium, 80333 München
lupomuc    | https://lupomuc.eltern-portal.org     | Luitpold-Gymnasium München, 80538 München
lwgschwab  | https://lwgschwab.eltern-portal.org   | Leonhard-Wagner-Gymnasium Schwabmünchen
mabogym    | https://mabogym.eltern-portal.org     | Max-Born-Gymnasium, 82110 Germering
marbugym   | https://marbugym.eltern-portal.org    | Marianum Buxheim Gymnasium des Schulwerks der Diözese Augsburg, 87740 Buxheim
marktgym   | https://marktgym.eltern-portal.org    | Gymnasium Marktbreit, 97340 Marktbreit
mathemuc   | https://mathemuc.eltern-portal.org    | Maria-Theresia-Gymnasium, 81541 München
maxgymuc   | https://maxgymuc.eltern-portal.org    | Maximiliansgymnasium München, 80803 München
mgf        | https://mgf.eltern-portal.org         | Maristengymnasium Fürstenzell, 94081
mggwue     | https://mggwue.eltern-portal.org      | Matthias-Grünewald-Gymnasium Würzburg, 97074 Würzburg
michamuc   | https://michamuc.eltern-portal.org    | Michaeli-Gymnasium München, 81671 München
mjsmuc     | https://mjsmuc.eltern-portal.org      | Staatliches Gymnasium Max-Josef-Stift München, 81677 München
mmgyvil    | https://mmgyvil.eltern-portal.org     | Maximilian-von-Montgelas-Gymnasium, 84137 Vilsbiburg
mogymuc    | https://mogymuc.eltern-portal.org     | Staatliches Gymnasium München-Moosach, 80993 München
moosgym    | https://moosgym.eltern-portal.org     | Karl-Ritter-von-Frisch-Gymnasium, 85368 Moosburg
mpgymel    | https://mpgymel.eltern-portal.org     | Martin-Pollich-Gymnasium Mellrichstadt, 97638 Mellrichstadt
mswas      | https://mswas.eltern-portal.org       | Mittelschule Wasserburg am Inn, 83512 Wasserburg am Inn
mtgyau     | https://mtgyau.eltern-portal.org      | Maria-Theresia-Gymnasium Augsburg, 86150 Augsburg
mtgyerl    | https://mtgyerl.eltern-portal.org     | Städtisches Marie-Therese-Gymnasium Erlangen, 91054 Erlangen
muebegy    | https://muebegy.eltern-portal.org     | Gymnasium Münchberg, 95213 Münchberg
muenomuc   | https://muenomuc.eltern-portal.org    | Gymnasium München-Nord, 80937 München
mwgyal     | https://mwgyal.eltern-portal.org      | Maria-Ward-Gymnasium Altötting, 84503 Altötting
mwgyau     | https://mwgyau.eltern-portal.org      | Maria-Ward-Gymnasium Augsburg, 86152 Augsburg
mwgygz     | https://mwgygz.eltern-portal.org      | Maria-Ward-Gymnasium Günzburg, 89312 Günzburg
mwnuegy    | https://mwnuegy.eltern-portal.org     | Maria-Ward-Gymnasium Nürnberg, 90489 Nürnberg
mwnuers    | https://mwnuers.eltern-portal.org     | Maria-Ward-Realschule Nürnberg, 90489 Nürnberg
mwrsn      | https://mwrsn.eltern-portal.org       | Maria Ward Realschule Neuhaus, 94152
nailagym   | https://nailagym.eltern-portal.org    | Hochfranken-Gymnasium Naila, 95119 Naila
neugynue   | https://neugynue.eltern-portal.org    | Neues Gymnasium Nürnberg, 90478 Nürnberg
neutragym  | https://neutragym.eltern-portal.org   | Gymnasium Neutraubling, 93073 Neutraubling
nfgymuc    | https://nfgymuc.eltern-portal.org     | Gymnasium Neufreimann, 80805 München
nkgwh      | https://nkgwh.eltern-portal.org       | Nikolaus-Kopernikus-Gymnasium Weißenhorn, 89264 Weißenhorn
nymph      | https://nymph.eltern-portal.org       | Nymphenburger Schulen, 80638 München
ohagym     | https://ohagym.eltern-portal.org      | Gymnasium Oberhaching, 82041 Oberhaching
ohgyerl    | https://ohgyerl.eltern-portal.org     | Ohm-Gymnasium Erlangen, 91052 Erlangen
olchigym   | https://olchigym.eltern-portal.org    | Gymnasium Olching, 82140 Olching
omgyneu    | https://omgyneu.eltern-portal.org     | Oskar-Maria-Graf-Gymnasium, 85375
opgypul    | https://opgypul.eltern-portal.org     | Otfried-Preußler-Gymnasium Pullach, 82049
ovmgymuc   | https://ovmgymuc.eltern-portal.org    | Oskar-von-Miller-Gymnasium München, 80803 München
ovtgym     | https://ovtgym.eltern-portal.org      | Otto-von-Taube-Gymnasium Gauting, 82131 Gauting
pafgym     | https://pafgym.eltern-portal.org      | Schyren-Gymnasium, 85276 Pfaffenhofen an der Ilm
peugyau    | https://peugyau.eltern-portal.org     | Peutinger-Gymnasium Augsburg, 86152 Augsburg
pfgyher    | https://pfgyher.eltern-portal.org     | Paul-Pfinzing-Gymnasium, 91217 Hersbruck
plagyans   | https://plagyans.eltern-portal.org    | Platen-Gymnasium Ansbach, 91522 Ansbach
prmpul     | https://prmpul.eltern-portal.org      | Erzbischöfliches Pater-Rupert-Mayer-Gymnasium Pullach, 82049
prmpulgs   | https://prmpulgs.eltern-portal.org    | Erzbischöfliche Pater-Rupert-Mayer-Grundschule Pullach, 82049
psmsgraf   | https://psmsgraf.eltern-portal.org    | Propst-Seyberer-Mittelschule Grafenau
puheigy    | https://puheigy.eltern-portal.org     | Gymnasium Puchheim, 82178 Puchheim
riegywue   | https://riegywue.eltern-portal.org    | Riemenschneider-Gymnasium Würzburg, 97070 Würzburg
riwagybay  | https://riwagybay.eltern-portal.org   | Richard-Wagner-Gymnasium Bayreuth, 95444 Bayreuth
roewuegy   | https://roewuegy.eltern-portal.org    | Röntgen-Gymnasium Würzburg, 97070 Würzburg
rottlaugy  | https://rottlaugy.eltern-portal.org   | Rottmayr-Gymnasium Laufen, 83410 Laufen
rsache     | https://rsache.eltern-portal.org      | Achental-Realschule Marquartstein
rsgcham    | https://rsgcham.eltern-portal.org     | Robert-Schuman-Gymnasium Cham
rsvat      | https://rsvat.eltern-portal.org       | Staatliche Realschule Vaterstetten, 85598 Vaterstetten
rudigyau   | https://rudigyau.eltern-portal.org    | Rudolf-Diesel-Gymnasium Augsburg, 86163 Augsburg
rugymue    | https://rugymue.eltern-portal.org     | Ruperti-Gymnasium, 84453 Mühldorf a. Inn
seligla    | https://seligla.eltern-portal.org     | Gymnasium der Schulstiftung Seligenthal, 84034 Landshut
seliglags  | https://seliglags.eltern-portal.org   | Grundschule der Schulstiftung Seligenthal, 84034 Landshut
seligws    | https://seligws.eltern-portal.org     | Wirtschaftsschule der Schulstiftung Seligenthal Landshut, 84034 Landshut
shr        | https://shr.eltern-portal.org         | Samuel-Heinicke-Realschule, 80992 München
siewuegym  | https://siewuegym.eltern-portal.org   | Siebold-Gymnasium Würzburg, 97070 Würzburg
simagygu   | https://simagygu.eltern-portal.org    | Simon-Marius-Gymnasium, 91710 Gunzenhausen
sontgym    | https://sontgym.eltern-portal.org     | Gymnasium Sonthofen, 87527 Sonthofen
sosgymuc   | https://sosgymuc.eltern-portal.org    | Städtisches Sophie-Scholl-Gymnasium München, 80804 München
spmshau    | https://spmshau.eltern-portal.org     | Sport-Mittelschule Hauzenberg
stagymu    | https://stagymu.eltern-portal.org     | Staffelsee-Gymnasium Murnau, 82418 Murnau am Staffelsee
stbgym     | https://stbgym.eltern-portal.org      | Gymnasium Starnberg, 82319 Starnberg
stgogyna   | https://stgogyna.eltern-portal.org    | St.-Gotthard-Gymnasium, 94557
stugylen   | https://stugylen.eltern-portal.org    | Erzbischöfliches St.-Ursula-Gymnasium, 50321 Brühl
tassimgy   | https://tassimgy.eltern-portal.org    | Tassilo-Gymnasium Simbach am Inn, 84359 Simbach
tgamuc     | https://tgamuc.eltern-portal.org      | Theresia-Gerhardinger-Gymnasium am Anger, 80331 München
tgrs       | https://tgrs.eltern-portal.org        | Erzbischöfliche Theresia-Gerhardinger-Mädchenrealschule, 81541 München
theheugym  | https://theheugym.eltern-portal.org   | Theodor-Heuss-Gymnasium Nördlingen, 86720 Nördlingen
theogymuc  | https://theogymuc.eltern-portal.org   | Städtisches Theodolinden-Gymnasium München, 81547 München
thergymuc  | https://thergymuc.eltern-portal.org   | Theresien-Gymnasium München, 80336 München
thomagymuc | https://thomagymuc.eltern-portal.org  | Städtisches Thomas-Mann-Gymnasium München, 81379 München
toelgvs    | https://toelgvs.eltern-portal.org     | Gabriel-von-Seidl-Gymnasium Bad Tölz, 83646 Bad Tölz
trugymuc   | https://trugymuc.eltern-portal.org    | Gymnasium Trudering, 81827 München
ufggym     | https://ufggym.eltern-portal.org      | Gymnasium Unterföhring, 85774 Unterföhring
ugriegym   | https://ugriegym.eltern-portal.org    | Gymnasium Untergriesbach, 94107
urstragym  | https://urstragym.eltern-portal.org   | Gymnasium der Ursulinen-Schulstiftung Straubing, 94315 Straubing
veihoegym  | https://veihoegym.eltern-portal.org   | Gymnasium Veitshöchheim, 97209
vhgybo     | https://vhgybo.eltern-portal.org      | Veit-Höser-Gymnasium Bogen, 94327 Bogen
visgyffb   | https://visgyffb.eltern-portal.org    | Viscardi-Gymnasium Fürstenfeldbruck, 82256 Fürstenfeldbruck
wbgl       | https://wbgl.eltern-portal.org        | Wolfgang-Borchert-Gymnasium Langenzenn, 90579 Langenzenn
weilgym    | https://weilgym.eltern-portal.org     | Gymnasium Weilheim i. OB, 82362 Weilheim in Oberbayern
welfen     | https://welfen.eltern-portal.org      | Welfen-Gymnasium Schongau, 86956 Schongau
wggselb    | https://wggselb.eltern-portal.org     | Walter-Gropius-Gymnasium Selb, 95100 Selb
wggymuc    | https://wggymuc.eltern-portal.org     | Städtisches Willi-Graf-Gymnasium München, 80804 München
whgga      | https://whgga.eltern-portal.org       | Werner-Heisenberg-Gymnasium Garching, 85748 Garching bei München
whgmuc     | https://whgmuc.eltern-portal.org      | Wilhelm-Hausenstein-Gymnasium München, 81925 München
widipogy   | https://widipogy.eltern-portal.org    | Wilhelm-Diess-Gymnasium Pocking, 94060 Pocking
wigywue    | https://wigywue.eltern-portal.org     | Wirsberg-Gymnasium Würzburg, 97070 Würzburg
willigym   | https://willigym.eltern-portal.org    | Willibald-Gluck-Gymnasium, 92318 Neumarkt in der Oberpfalz
witgymuc   | https://witgymuc.eltern-portal.org    | Wittelsbacher-Gymnasium München, 80335 München
wkrstauf   | https://wkrstauf.eltern-portal.org    | Walter-Klingenbeck-Schule Taufkirchen, 82024 Taufkirchen
wmrstrau   | https://wmrstrau.eltern-portal.org    | Walter-Mohr-Realschule Traunreut, 83301 Traunreut
wvsgsau    | https://wvsgsau.eltern-portal.org     | Werner-von-Siemens-Grundschule Augsburg, 86163 Augsburg
wvsgymuc   | https://wvsgymuc.eltern-portal.org    | Städtisches Werner-von-Siemens-Gymnasium München, 81735 München
wwgybay    | https://wwgybay.eltern-portal.org     | Wirtschaftswissenschaftliches und Naturwissenschaftlich-technologisches Gymnasium der Stadt Bayreuth, 95448 Bayreuth
